pca.screeplot: pca.screeplot

Description Usage Arguments Examples

View source: R/pca.screeplot.R

Description

Plots the percentage of explained variance against the number of the principal component.

Usage

1
pca.screeplot(data, center = T, scale = F, type = 1)

Arguments

data

The data used to build the screeplot

center

Column centering the data (default = TRUE). If center is TRUE then centering is done by subtracting the column means (omitting NA's) of x from their corresponding columns, and if center is FALSE, no centering is done.

scale

Scaling the data (default = FALSE). If scale is TRUE then scaling is done by dividing the (centered) columns of x by their standard deviations if center is TRUE, and the root mean square otherwise. If scale is FALSE, no scaling is done.

type

Type of screeplot (1 = dots and lines, 2 = barplot)

Examples

1
2

StefaanVerwimp/Biplot documentation built on Feb. 10, 2021, 9:37 a.m.