Description Usage Arguments Examples
A customizable correlational biplot function. PC's are scaled to unit variance.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 |
data |
The data used to build the biplot |
center |
Column centering the data (default = |
scale |
Scaling the data (default = |
pcx |
Which principal component to plot on the X-axis (default = 1) |
pcy |
Which principal component to plot on the Y-axis (default = 2) |
groups |
A vector from which the unique values are used to color the observations |
col |
Vector of colors, to color observations. Needs to be equal to the number of unique values of |
pch |
Either an integer specifying a symbol or a single character to be used as the default in plotting points. See |
ellipse |
Whether to add confidence ellipses to the different groups |
ellipse.alpha |
Alpha transparency value for the fill color (0 = transparent, 1 = opaque) |
ellipse.conf |
Confidence limit for ellipses, e.g. 0.68. If given, the corresponding sd or se is multiplied with the corresponding value found from the Chi-squared distribution with 2df. |
ellipse.lwd |
Line width of ellipse border |
arrow.options |
List to define options for the variable arrows (for all options see |
label.options |
List to define options for the variable labels (for all options see |
abbrev |
Whether to abbreviate the variable names |
circle |
Whether to add a unit circle. Only applies if data is scaled! |
circle.options |
List to define options for the unit circle (for all options see |
legend |
Whether to add a legend |
legend.pos |
Position of the legend |
... |
Other graphical parameters, see |
1 2 3 4 5 6 | data(iris)
pca.biplot(iris[1:4])
pca.biplot(iris[,-5], col = c("#00AFBB", "#E7B800", "#FC4E07"), groups = iris$Species,
legend = F, arrow.options = list(col="blue", angle = 20, length = 0.15))
pca.biplot(iris[,-5], scale = T, col = c("#00AFBB", "#E7B800", "#FC4E07"), groups = iris$Species,
ellipse = T, pch = 16, legend.pos = 'topright')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.