Description Usage Arguments Examples
An interactive 3D biplot. PC's are scaled to unit variance.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 | pca.biplot3d(
data,
center = TRUE,
scale = FALSE,
pcx = 1,
pcy = 2,
pcz = 3,
col = "black",
groups = NULL,
bg = "white",
type = "sphere",
r = 0.05,
aspect3d = c(1, 1, 1),
abbrev = FALSE,
arrow.col = "black",
label.col = "darkblue",
label.cex = 1,
simple.axis = FALSE,
box = FALSE,
grid = FALSE,
ellipse = FALSE,
ellipse.conf = 0.68,
ellipse.alpha = 0.2,
ellipse.shade = TRUE,
ellipse.wire = FALSE,
...
)
|
data |
The data used to build the biplot |
center |
Column centering the data (default = |
scale |
Scaling the data (default = |
pcx |
Which principal component to plot on the X-axis (default = 1) |
pcy |
Which principal component to plot on the Y-axis (default = 2) |
pcz |
Which principal component to plot on the Z-axis (default = 3) |
col |
Defines color of the observations, only if no group is defined |
groups |
A vector from which the unique values are used to color the observations |
bg |
Background color |
type |
Type of plot / Presentation of observations. Options: |
r |
Vector or single value defining the sphere radius/radii |
aspect3d |
Vector used to set apparent ratios of the x, y, and z axes of the current bounding box |
abbrev |
Whether to abbreviate the variable names |
arrow.col |
Color of the variable arrow |
label.col |
Color of the variable label |
label.cex |
Size of the variable label |
simple.axis |
Uses |
box |
Whether to draw a box (only if using |
grid |
Adds a reference grid if |
ellipse |
Whether to add confidence ellipses to groups (to display this on the plot, either |
ellipse.conf |
Confidence limit for ellipses |
ellipse.alpha |
Alpha transparency value for the ellipse (0 = transparent, 1 = opaque) |
ellipse.shade |
Draws ellipse as a surface |
ellipse.wire |
Draws ellipse as line segments |
... |
Material properties (see |
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.